#################################################################################################################################
###### Williams, S.T., Maree, N., Taylor, P., Belmain, S.R., Keith, M. and Swanepoel, L.H (in review)                       #####
###### Predation by small mammalian carnivores in rural agro-ecosystems: An undervalued ecosystem service?                  #####
###### Ecosystem Services                                                                                                   #####
#####                                                                                                                       #####  
###### Appendix : JAGS code for multispecies occupancy model used to analyze camera-trapping                                #####
###### data from two villages in the Vhembe Distrist, Limpopo provice, South Africa                                         #####
###### Code prepared by Lourens Swanepoel & Sam Williams                                                                    #####
#################################################################################################################################

### Get data
  data   <- read.table("SpData.txt", header = TRUE)
#### Summary of data
  str     (data)
  head    (data)
  summary (data)
# Create species lists
  (species.list           <- levels (data$spec.name))
  (spec.name.list         <- tapply (data$specid, data$spec.name, mean))
  (spec.id.list           <- unique (data$specid))
  (ordered.spec.name.list <- spec.name.list[order(spec.name.list)])
# Select detection/nondetection data
  DET <- cbind(data$det01, data$det02, data$det03, data$det04, data$det05, data$det06, data$det07, data$det08,data$det09,data$det10)  # Detection/nondetection
  (n.surveys=length(DET[1,]))
  (n.species=length(species.list1 <- levels(data$spec.name)))
  n.quadrats=171 # nr of camera trapping sites
# Put detection data into 3D array: site x rep x species
  Y <- array(NA, dim = c(n.quadrats, n.surveys, n.species))

for(i in 1:n.species){
  Y[,,i] <- DET[((i-1)*n.quadrats+1):(i*n.quadrats),]
}

  dimnames(Y) <- list(NULL, NULL, ordered.spec.name.list)
  nsite <- dim(Y)[1] # same as n.quadrats
  nspec = n.species
  nrep = n.surveys

  Y [Y>1] <- 1

# Augment data set
nz <- 14    # Number of potential species in superpopulation - we detected 9 + 13 =23
Yaug <- array(0, dim=c(nsite, nrep, nspec+nz))
Yaug[,,1:nspec] <- Y

#######################################
# Get covariate data
# Check for multicollinearity 
#######################################
#pc.crops in grid cell (%)
  PC.CROPS <- data$pc.crops[1:nsite]
  (mean.pc.crops <- mean(PC.CROPS, na.rm = TRUE))
  (sd.pc.crops <- sd(PC.CROPS , na.rm = TRUE))
  perc.crops <- (PC.CROPS  - mean.pc.crops)/sd.pc.crops
#pc.grazing in grid cell (%)
  GRAZING <- data$pc.grazing[1:nsite]
  (mean.pc.grazing <- mean(GRAZING, na.rm = TRUE))
  (sd.pc.grazing <- sd(GRAZING, na.rm = TRUE))
  perc.grazing <- (GRAZING - mean.pc.grazing)/sd.pc.grazing
#pc.settlement in grid cell (%)
  SETTL <- data$pc.settlement[1:nsite]
  (mean.set <- mean(SETTL, na.rm = TRUE))
  (sd.set <- sd(SETTL, na.rm = TRUE))
  perc.settlemet <- (SETTL - mean.set)/sd.set
#FreqDog in grid cell (RAI - nr/1000 camera trap nights)
  DOG <- data$FreqDog[1:nsite]
  (mean.dog <- mean(DOG, na.rm = TRUE))
  (sd.dog <- sd(DOG, na.rm = TRUE))
  dog <- (DOG - mean.dog)/sd.dog
  #FreqCat in grid cell (RAI - nr/1000 camera trap nights)
  CAT       <- data$FreqCat[1:nsite]
  (mean.cat <- mean(CAT, na.rm = TRUE))
  (sd.cat   <- sd(CAT, na.rm = TRUE))
  cat       <- (CAT - mean.cat)/sd.cat  
#FreqHumans in grid cell (RAI - nr/1000 camera trap nights)
  HUMAN <- data$FreqHumans[1:nsite]
  (mean.hum <- mean(HUMAN, na.rm = TRUE))
  (sd.hum <- sd(HUMAN, na.rm = TRUE))
  human <- (HUMAN - mean.hum)/sd.hum
#FreqLivestock in grid cell (RAI - nr/1000 camera trap nights)
  LIVEST <- data$FreqLivestock[1:nsite]
  (mean.liv <- mean(LIVEST, na.rm = TRUE))
  (sd.liv <- sd(LIVEST, na.rm = TRUE))
  livestock <- (LIVEST - mean.liv)/sd.liv
# make DF 
  covars <- data.frame(PC.CROPS, GRAZING, SETTL, DOG, CAT, HUMAN, LIVEST)
  pairs(covars)
  hist(PC.CROPS)
  hist(GRAZING)
  hist(SETTL)
  hist(DOG)
  hist(CAT)
  hist(HUMAN)
  library(usdm)
  vif(covars) # drop PC.CROPS, GRAZING, SETTL
  covars1 <- data.frame(DOG, CAT, HUMAN, LIVEST)
  vif(covars1) # rather drop human and keep dog
  covars2 <- data.frame(DOG, CAT, LIVEST)
  vif(covars2)  # keep all three
#######################################
# Covariates on psi - occupancy
# Looking at two things - how dogs and cats affect occ 
#######################################

#grid cell
  grid     <-data$point[1:nsite]
  grid=as.numeric(grid)
  summary(grid)
  (ngrid = max(grid))
#FreqDog in grid cell (RAI - nr/1000 camera trap nights)
  DOG       <- data$FreqDog[1:nsite]
  (mean.dog <- mean(DOG, na.rm = TRUE))
  (sd.dog   <- sd(DOG, na.rm = TRUE))
  dog       <- (DOG - mean.dog)/sd.dog
#FreqCat in grid cell (RAI - nr/1000 camera trap nights)
  CAT       <- data$FreqCat[1:nsite]
  (mean.cat <- mean(CAT, na.rm = TRUE))
  (sd.cat   <- sd(CAT, na.rm = TRUE))
  cat       <- (CAT - mean.cat)/sd.cat
#FreqLivestock in grid cell (RAI - nr/1000 camera trap nights)
  LIVEST <- data$FreqLivestock[1:nsite]
  (mean.liv <- mean(LIVEST, na.rm = TRUE))
  (sd.liv <- sd(LIVEST, na.rm = TRUE))
  livestock <- (LIVEST - mean.liv)/sd.liv  
  
#######################################
# Covariates on detection
#######################################
#survey date
  date <- cbind(data$date01, data$date02, data$date03, data$date04, data$date05, data$date06, data$date07, 
                 data$date08,data$date09,data$date10)[1:nsite,]
  (mean.date <- mean(date, na.rm = TRUE))
  (sd.date   <- sd(c(date), na.rm = TRUE))
  date       <- (date - mean.date) / sd.date
  date[is.na(date)] <- 0
##########################################################
# MODEL ON DOG, CAT AND LIVESTOCK INFLUENCE on OCCUPANCY #
##########################################################
# Bundle data
  win.data <- list(Y = Yaug, nsite = dim(Y)[1], nrep = dim(Y)[2], nspec = dim(Y)[3], date = date, nz=nz, M=nspec+nz,
                    cat = cat, dog = dog, livestock=livestock)
# Specify model in BUGS language
  sink("ES_MS.txt")
  cat("
      model {
      
      # Priors
      omega ~ dunif(0,1)
      # Prior for species spesific effects on occupancy and detection
      for(k in 1:(M)){
      lpsi[k] ~ dnorm(mu.lpsi, tau.lpsi)    # Hyperparams describe community
      betalpsi1 [k] ~ dnorm(mu.betalpsi1, tau.betalpsi1) # cat
      betalpsi2 [k] ~ dnorm(mu.betalpsi2, tau.betalpsi2) # dog
      betalpsi3 [k] ~ dnorm(mu.betalpsi3, tau.betalpsi3) # livestock
      
      lp[k] ~ dnorm(mu.lp, tau.lp)
      betalp1 [k] ~ dnorm(mu.betalp1, tau.betalp1) #only for date as detection covariate
      }
      
      # Hyperpriors
      # For the model of occupancy
      mu.lpsi ~ dnorm(0,0.01)
      tau.lpsi <- pow(sd.lpsi, -2)
      sd.lpsi ~ dunif(0,5)
      
      mu.betalpsi1 ~ dnorm(0, 0.01)
      tau.betalpsi1 <- pow(sd.betalpsi1, -2)
      sd.betalpsi1 ~ dunif(0,3)
      
      mu.betalpsi2 ~ dnorm(0, 0.01)
      tau.betalpsi2 <- pow(sd.betalpsi2, -2)
      sd.betalpsi2 ~ dunif(0,3)
      
      mu.betalpsi3 ~ dnorm(0, 0.01)
      tau.betalpsi3 <- pow(sd.betalpsi3, -2)
      sd.betalpsi3 ~ dunif(0,3)
      
      # for the model of detection
      mu.lp ~ dnorm(0,0.01)
      tau.lp <- pow(sd.lp, -2)
      sd.lp ~ dunif(0,3)
      
      mu.betalp1 ~ dnorm(0,0.01)
      tau.betalp1 <- pow(sd.betalp1, -2)
      sd.betalp1 ~ dunif(0,3)
      
      # Superpopulation process: Ntotal species sampled out of M available
      for(k in 1:(M)){
      w[k] ~ dbern(omega)
      }
      
      # Likelihood
      # Ecological model for true occurrence (process model), occupancy
      for (k in 1:M){
      for (i in 1:nsite) {
      logit(psi[i,k]) <- lpsi[k] + betalpsi1[k] * cat[i] + betalpsi2[k] * dog[i] + betalpsi3[k] * livestock [i]
      mu.psi[i,k] <- w[k] * psi[i,k]
      z[i,k] ~ dbern(mu.psi[i,k])
      }
      }
      
      # Observation model for replicated detection/nondetection observations
      for(k in 1:(M)){
      for (i in 1:nsite){
      for(j in 1:nrep){
      logit(p[i,j,k]) <- lp[k] + betalp1[k] * date[i,j]
      p.eff[i,j,k] <- z[i,k] * p[i,j,k]
      Y[i,j,k] ~ dbern(p.eff[i,j,k])
      ### generate new data from model under consideration
      new.y[i,j,k] ~ dbern(p.eff[i,j,k])
      
      ### calculate Freeman-Tukey residuals for real and new data
      res[i,j,k] <- (Y[i,j,k] - sqrt(p.eff[i,j,k]))^2
      new.res[i,j,k] <- (new.y[i,j,k] - sqrt(p.eff[i,j,k]))^2
      }
      ###sum residuals over occasions
      R1[i,k] <- sum(res[i, ,k])
      new.R1[i,k] <- sum(new.res[i, , k])
      }
      ###sum residuals over sites
      R2[k] <- sum(R1[, k])
      new.R2[k] <- sum(new.R1[, k])
      }
      
      ###sum residuals over (observed) species (all species were observed)
      R3 <- sum(R2[])
      new.R3 <- sum(new.R2[])
      
      # Derived quantities
      for(k in 1:(M)){
      occ.fs[k] <- sum(z[,k])             # Number of occupied sites among the 171
      }
      for (i in 1:nsite) {
      Nsite[i] <- sum(z[i,])              # Number of occurring species at each camera site
      }
      n0 <- sum(w[(nspec+1):(nspec+nz)])  # Number of unseen species
      Ntotal <- sum(w[])                  # Total community size
      
      }
      ",fill = TRUE)
  sink()
  
# Initial values
  zst   <- apply(Yaug, c(1,3), max)  # Observed occurrence as starting values for z
  zst[is.na(zst)] <- 1
  wst   <- c(rep(1, nspec+nz))
  inits <- function() list(z = zst, w = wst, 
                         lpsi = rnorm(n = nspec+nz),
                         betalpsi1 = rnorm(n = nspec+nz),
                         betalpsi2 = rnorm(n = nspec+nz),
                         betalpsi3 = rnorm(n = nspec+nz)) 



# Parameters monitored
  params <- c( "mu.lpsi", "sd.lpsi", "mu.lp", "mu.betalp1", "sd.betalp1", "sd.lp",
             "mu.betalpsi1", "sd.betalpsi1", "mu.betalpsi2", "sd.betalpsi2","mu.betalpsi3", "sd.betalpsi3",
             "betalpsi1", "betalpsi2","betalpsi3", "omega", "lpsi", "lp", "betalp1",
             "R3", "new.R3", "Nsite", "Ntotal")
# MCMC settings
  ni <- 50000
  nt <- 10
  nb <- 5000
  nc <- 3

# Call JAGS from R
  library("jagsUI")

# run JAGS
  system.time(out_ES_MS <- jags(win.data, inits, params, "ES_MS.txt",
                           n.chains = nc, n.thin = nt, n.iter = ni, n.adapt = nb, parallel=TRUE) )
# Look at output
  View(out_ES_MS) # jagout
 library(coda)  
  #crosscorr(out_ES_MS$samples)
  #with(out_ES_MS$sims.list, plot( mu.betalpsi1,  mu.betalpsi3))
#### How many species estimated?
  mean(out_ES_MS$mean$Ntotal)
#### Look at distrubtion on Ntotal 
  library(wiqid)
  plotPost(out_ES_MS$sims.list$Ntotal, showCurve=TRUE, showMode = TRUE, shadeHDI='pink', ROPE=c(9,16), xlab="Ntotal") 
  
  plotPost(out_ES_MS$sims.list$Nsite[,1], showCurve=FALSE, showMode = FALSE, shadeHDI='pink', xlab="Ntotal") 


  
#### Function to extract mode, taking the maximum of a density estimate
#### get data for Ntotal from MCMC list
  mode.es <- out_ES_MS$sims.list$Ntotal  
  estimate_mode <- function(s) {
    d <- density(s)
    d$x[which.max(d$y)]
  }
  estimate_mode(mode.es)  
 
# What is the prop to detect >21 species?  
  mean(out_ES_MS$sims.list$Ntotal > 16)


# check model fit
  pp.check(out_ES_MS, "R3", "new.R3")

### plot CAT effects CAT 
  plot(out_ES_MS$summary[12:20,1], 1:9, xlim = c(-4, 4), xlab = "Effect size", ylab = "Species number", main = "Effect of CAT on occupancy")
  abline(v = 0, lwd = 1, col = "black")
  segments(out_ES_MS$summary[12:20,3], 1:9, out_ES_MS$summary[12:20,7], 1:9, col = "grey", lwd = 1)
  sig3.1 <- (out_ES_MS$summary[12:20,3]<0 & out_ES_MS$summary[12:20,7]<0) + (out_ES_MS$summary[12:20,3]>0 & out_ES_MS$summary[12:20,7]>0)
  segments(out_ES_MS$summary[12:20,3][sig3.1==1], (1:9)[sig3.1==1], out_ES_MS$summary[12:20,7][sig3.1==1], (1:9)[sig3.1==1], col = "blue", lwd = 2)
  abline(v=out_ES_MS$summary[6,1], lwd=3, col="red") # mean community effect
  abline(v=out_ES_MS$summary[6,c(3,7)], lwd=2, col="red", lty=2) # 95% BCI


### plot effects DOGS 
  plot(out_ES_MS$summary[35:43,1], 1:9, xlim = c(-4, 4), xlab = "Effect size", ylab = "Species number", main = "Effect of DOG on occupancy")
  abline(v = 0, lwd = 1, col = "black")
  segments(out_ES_MS$summary[35:43,3], 1:9, out_ES_MS$summary[35:43,7], 1:9, col = "grey", lwd = 1)
  sig3.1 <- (out_ES_MS$summary[35:43,3]<0 & out_ES_MS$summary[35:43,7]<0) + (out_ES_MS$summary[35:43,3]>0 & out_ES_MS$summary[35:43,7]>0)
  segments(out_ES_MS$summary[35:43,3][sig3.1==1], (1:9)[sig3.1==1], out_ES_MS$summary[35:43,7][sig3.1==1], (1:9)[sig3.1==1], col = "blue", lwd = 2)
  abline(v=out_ES_MS$summary[8,1], lwd=3, col="red")
  abline(v=out_ES_MS$summary[8,c(3,7)], lwd=2, col="red", lty=2)


### plot effects LIVESTOCK 
  plot(out_ES_MS$summary[58:66,1], 1:9, xlim = c(-4, 4), xlab = "Effect size", ylab = "Species number", main = "Effect of LIVESTOCK on occupancy")
  abline(v = 0, lwd = 1, col = "black")
  segments(out_ES_MS$summary[58:66,3], 1:9, out_ES_MS$summary[58:66,7], 1:9, col = "grey", lwd = 1)
  sig3.1 <- (out_ES_MS$summary[58:66,3]<0 & out_ES_MS$summary[58:66,7]<0) + (out_ES_MS$summary[58:66,3]>0 & out_ES_MS$summary[58:66,7]>0)
  segments(out_ES_MS$summary[58:66,3][sig3.1==1], (1:9)[sig3.1==1], out_ES_MS$summary[58:66,7][sig3.1==1], (1:9)[sig3.1==1], col = "blue", lwd = 2)
  abline(v=out_ES_MS$summary[10,1], lwd=3, col="red")
  abline(v=out_ES_MS$summary[10,c(3,7)], lwd=2, col="red", lty=2)

  
### plot effects JULIAN date on detection 
  plot(out_ES_MS$summary[128:136,1], 1:9, xlim = c(-4, 4), xlab = "Effect size", ylab = "Species number", main = "Effect of Julian date on p")
  abline(v = 0, lwd = 1, col = "black")
  segments(out_ES_MS$summary[128:136,3], 1:9, out_ES_MS$summary[128:136,7], 1:9, col = "grey", lwd = 1)
  sig3.1 <- (out_ES_MS$summary[128:136,3]<0 & out_ES_MS$summary[128:136,7]<0) + (out_ES_MS$summary[128:136,3]>0 & out_ES_MS$summary[128:136,7]>0)
  segments(out_ES_MS$summary[128:136,3][sig3.1==1], (1:9)[sig3.1==1], out_ES_MS$summary[128:136,7][sig3.1==1], (1:9)[sig3.1==1], col = "blue", lwd = 2)
  abline(v=out_ES_MS$summary[4,1], lwd=3, col="red")
  abline(v=out_ES_MS$summary[4,c(3,7)], lwd=2, col="red", lty=2)
 
#### species on detection   
  layout(matrix(c(1,2,3,4,5,6,7,8,9), 3, 3, byrow = TRUE))
  layout.show(9)
  plotPost(plogis(out_ES_MS$sims.list$lp[,1]), showCurve=TRUE, showMode = FALSE, shadeHDI='pink', ROPE=c(9,16), xlab="P")
  plotPost(plogis(out_ES_MS$sims.list$lp[,2]), showCurve=TRUE, showMode = FALSE, shadeHDI='pink', ROPE=c(9,16), xlab="P")
  plotPost(plogis(out_ES_MS$sims.list$lp[,3]), showCurve=TRUE, showMode = FALSE, shadeHDI='pink', ROPE=c(9,16), xlab="P")
  plotPost(plogis(out_ES_MS$sims.list$lp[,4]), showCurve=TRUE, showMode = FALSE, shadeHDI='pink', ROPE=c(9,16), xlab="P")
  plotPost(plogis(out_ES_MS$sims.list$lp[,5]), showCurve=TRUE, showMode = FALSE, shadeHDI='pink', ROPE=c(9,16), xlab="P")
  plotPost(plogis(out_ES_MS$sims.list$lp[,6]), showCurve=TRUE, showMode = FALSE, shadeHDI='pink', ROPE=c(9,16), xlab="P")
  plotPost(plogis(out_ES_MS$sims.list$lp[,7]), showCurve=TRUE, showMode = FALSE, shadeHDI='pink', ROPE=c(9,16), xlab="P")
  plotPost(plogis(out_ES_MS$sims.list$lp[,8]), showCurve=TRUE, showMode = FALSE, shadeHDI='pink', ROPE=c(9,16), xlab="P")
  plotPost(plogis(out_ES_MS$sims.list$lp[,9]), showCurve=TRUE, showMode = FALSE, shadeHDI='pink', ROPE=c(9,16), xlab="P")
  # mean p for each of detcted species, and their mean
  mean(plogis(out_ES_MS$sims.list$lp[,1]))
  mean(plogis(out_ES_MS$sims.list$lp[,2]))
  mean(plogis(out_ES_MS$sims.list$lp[,3]))
  mean(plogis(out_ES_MS$sims.list$lp[,4]))
  mean(plogis(out_ES_MS$sims.list$lp[,5]))
  mean(plogis(out_ES_MS$sims.list$lp[,6]))
  mean(plogis(out_ES_MS$sims.list$lp[,8]))
  mean(plogis(out_ES_MS$sims.list$lp[,9]))
  mean(plogis(out_ES_MS$sims.list$lp[,1:9])) #mean for detected species
  
  par(mfrow=c(1,1))
  
  
### sp per landuse; use the robust estimates for Nsites
### Get the landuse table  
  box <- read.table("box1.txt", header = TRUE)
### get estimates of sp richness for vyeboom
    vye.site.data<-data.frame(out_ES_MS$summary[242:323,1], out_ES_MS$summary[242:323,3], out_ES_MS$summary[242:323,7], box$land.use[90:171])
      colnames(vye.site.data)<- c("sp.nr", "min", "max", "lu")
  ### get robust estimates of sp richness for kndengeza    
  kn.site.data<-data.frame(out_ES_MS$summary[153:241,1], out_ES_MS$summary[153:241,3], out_ES_MS$summary[153:241,7], box$land.use[1:89])
 colnames(kn.site.data)<- c("sp.nr", "min", "max", "lu")
  library(plyr)
#### get only robust estimets for Vye, exlude where 95 HDI overlap zero
  #Vye.robust.sp<-vye.site.data %>%
   # filter(min>0) 
 ## Mean nr of species per landuse for Vyeboom
  aggregate(. ~ lu, vye.site.data[-2], mean) 
  
  #Kn.robust.sp<-kn.site.data %>%
   # filter(min>0) 
  aggregate(. ~ lu, kn.site.data[-2], mean) # nr sp per landuse on robust estimates
  
###plot 
  
    #cdata <- ddply(vye.site.data, "lu", summarise,
     #            N    = length(sp.nr ),
      #           mean = mean(sp.nr ),
       #          sd   = sd(sp.nr ),
        #         se   = sd / sqrt(N))
  
  #  pd <- position_dodge(0.78)
   # ggplot(cdata, aes(x=lu, y = mean, group = lu)) +
    #draws the means
    #geom_point(position=pd) +
    #draws the CI error bars
    #geom_errorbar(data=cdata, aes(ymin=mean-2*se, ymax=mean+2*se, 
     #                             color=lu), width=.1, position=pd)
  
  boxplot(vye.site.data$sp.nr ~ vye.site.data$lu, ylim = c(0, 5), main="",
          xlab="", ylab="Species Richness")
  boxplot(kn.site.data$sp.nr ~ kn.site.data$lu, ylim = c(0, 5), main="",
          xlab="", ylab="Species Richness") 
  
#  box <- read.table("box1.txt", header = TRUE)
  boxplot(out_ES_MS$summary[153:241,1]~box$land.use[1:89], ylim = c(0, 5), main="",
       xlab="", ylab="Species Richness")
  boxplot(out_ES_MS$summary[242:323,1]~box$land.use[90:171], ylim = c(0, 5), main="",
        xlab="", ylab="Species Richness")

## plot output to map
  library(maptools)
  library(gstat)
  library(raster)
  library(rgdal)
  library(rasterVis)
  library(RColorBrewer)
  library(ggplot2)
## Get camera trap data
  library(readxl)
  CTraps <- read_excel("/Users/Sam/Dropbox/R_working_dropbox/ES revisions 7/CameraTraps.xls")
  
##### Plot on map for KD #######
  head(CTraps)
# Cat heat map
  cat.map<-data.frame(data$FreqCat[1:89],CTraps$X[1:89], CTraps$Y[1:89], CTraps$StationID[1:89])
  colnames(cat.map) <- c("freqcat", "x", "y" , "trap.id")
  names(cat.map)
  coordinates(cat.map) = ~x + y
  plot(cat.map)
  #locator(4) # use this to set the extent of grid
  x.range <- as.numeric(c(30.38109, 30.44746))  # min/max longitude of the interpolation area
  y.range <- as.numeric(c(-23.34059, -23.30166))  # min/max latitude of the interpolation area
  grd <- expand.grid(x = seq(from = x.range[1], to = x.range[2], by = 0.0001), y = seq(from = y.range[1], 
                                                                                   to = y.range[2], by = 0.0001))  # expand points to grid
  coordinates(grd) <- ~x + y
  gridded(grd) <- TRUE
  plot(grd, cex = 1.5, col = "grey")
  points(cat.map, pch = 1, col = "red", cex = 1)
  cat.idw<-idw(formula=freqcat ~ 1, locations=cat.map, newdata=grd)
  cat.r = raster(cat.idw["var1.pred"])
  plot(cat.r)
  mapPalette <- colorRampPalette(c("grey", "yellow", "orange", "red"))
  plot(cat.r, col= mapPalette(100), axes = F, box = FALSE, main ="CAT heatmap")
# Dog heat map
  data$FreqDog
  dog.map<-data.frame(data$FreqDog[1:89],CTraps$X[1:89], CTraps$Y[1:89], CTraps$StationID[1:89])
  colnames(dog.map) <- c("freqdog", "x", "y" , "trap.id")
  names(dog.map)
  coordinates(dog.map) = ~x + y
  dog.idw<-idw(formula=freqdog ~ 1, locations=dog.map, newdata=grd)
  dog.r = raster(dog.idw["var1.pred"])
  plot(dog.r)
  mapPalette <- colorRampPalette(c("grey", "yellow", "orange", "red"))
  plot(dog.r, col= mapPalette(100), axes = F, box = FALSE, main ="DOG heatmap")
  
# Livestock heat map
  livestock.map<-data.frame(data$FreqLivestock[1:89],CTraps$X[1:89], CTraps$Y[1:89], CTraps$StationID[1:89])
  colnames(livestock.map) <- c("freqlivestock", "x", "y" , "trap.id")
  names(livestock.map)
  coordinates(livestock.map) = ~x + y
  livestock.idw<-idw(formula=freqlivestock ~ 1, locations=livestock.map, newdata=grd)
  livestock.r = raster(livestock.idw["var1.pred"])
  plot(livestock.r)
  mapPalette <- colorRampPalette(c("grey", "yellow", "orange", "red"))
  plot(livestock.r, col= mapPalette(100), axes = F, box = FALSE, main ="LIVESTOCK heatmap")

##  ## Species map for KN
  carsp.map<-data.frame(out_ES_MS$summary[153:241,1], out_ES_MS$summary[153:241,3], CTraps$X[1:89], CTraps$Y[1:89], CTraps$StationID[1:89])
  colnames(carsp.map) <- c("carsp","min", "x", "y" , "trap.id")
  #carsp.map<-carsp.map %>%
   # filter(min>0)
  names(carsp.map)
  coordinates(carsp.map) = ~x + y
  carsp.idw<-idw(formula=carsp ~ 1, locations=carsp.map, newdata=grd)
  carsp.r = raster(carsp.idw["var1.pred"])
  plot(carsp.r)
  mapPalette <- colorRampPalette(c("grey", "yellow", "orange", "red"))
  plot(carsp.r, col= mapPalette(100), axes = F, box = FALSE, main ="Small carnivore species richness")
########## END KD #########
##### Plot on map for VYE #####  
  head(CTraps)
  # Cat heat map
  cat.map.v<-data.frame(data$FreqCat[90:171],CTraps$X[90:171], CTraps$Y[90:171], CTraps$StationID[90:171])
  colnames(cat.map.v) <- c("freqcat", "x", "y" , "trap.id")
  names(cat.map.v)
  coordinates(cat.map.v) = ~x + y
  plot(cat.map.v)
  #locator(4) # use this to set the extent of grid
  x.range.v <- as.numeric(c(30.36317, 30.43170))  # min/max longitude of the interpolation area
  y.range.v <- as.numeric(c(-23.17610, -23.13424))  # min/max latitude of the interpolation area
  grd.v <- expand.grid(x = seq(from = x.range.v[1], to = x.range.v[2], by = 0.0001), y = seq(from = y.range.v[1], 
                                                                                       to = y.range.v[2], by = 0.0001))  # expand points to grid
  coordinates(grd.v) <- ~x + y
  gridded(grd.v) <- TRUE
  plot(grd.v, cex = 1.5, col = "grey")
  points(cat.map.v, pch = 1, col = "red", cex = 1)
  cat.idw.v<-idw(formula=freqcat ~ 1, locations=cat.map.v, newdata=grd.v)
  cat.r.v = raster(cat.idw.v["var1.pred"])
  plot(cat.r.v)
  mapPalette <- colorRampPalette(c("grey", "yellow", "orange", "red"))
  plot(cat.r.v, col= mapPalette(100), axes = F, box = FALSE, main ="CAT heatmap")
  # Dog heat map
  dog.map.v<-data.frame(data$FreqDog[90:171],CTraps$X[90:171], CTraps$Y[90:171], CTraps$StationID[90:171])
  colnames(dog.map.v) <- c("freqdog", "x", "y" , "trap.id")
  names(dog.map.v)
  coordinates(dog.map.v) = ~x + y
  dog.idw.v<-idw(formula=freqdog ~ 1, locations=dog.map.v, newdata=grd.v)
  dog.r.v = raster(dog.idw.v["var1.pred"])
  plot(dog.r.v)
  mapPalette <- colorRampPalette(c("grey", "yellow", "orange", "red"))
  plot(dog.r.v, col= mapPalette(100), axes = F, box = FALSE, main ="DOG heatmap")
  # Livestock heat map
  livestock.map.v<-data.frame(data$FreqLivestock[90:171],CTraps$X[90:171], CTraps$Y[90:171], CTraps$StationID[90:171])
  colnames(livestock.map.v) <- c("freqlivestock", "x", "y" , "trap.id")
  names(livestock.map.v)
  coordinates(livestock.map.v) = ~x + y
  livestock.idw.v<-idw(formula=freqlivestock ~ 1, locations=livestock.map.v, newdata=grd.v)
  livestock.r.v = raster(livestock.idw.v["var1.pred"])
  plot(livestock.r.v)
  mapPalette <- colorRampPalette(c("grey", "yellow", "orange", "red"))
  plot(livestock.r.v, col= mapPalette(100), axes = F, box = FALSE, main ="LIVESTOCK heatmap")
  ## Species map for VYE
  carsp.map.v<-data.frame(out_ES_MS$summary[242:323,1], out_ES_MS$summary[242:323,3], CTraps$X[90:171], CTraps$Y[90:171], CTraps$StationID[90:171])
  colnames(carsp.map.v) <- c("carsp", "min", "x", "y" , "trap.id")
  # select only non zero overlapping sites for Nsite
  #carsp.map.v<-carsp.map.v %>%
   # filter(min>0)
  names(carsp.map.v)
  coordinates(carsp.map.v) = ~x + y
  carsp.idw.v<-idw(formula=carsp ~ 1, locations=carsp.map.v, newdata=grd.v)
  carsp.r.v = raster(carsp.idw.v["var1.pred"])
  plot(carsp.r.v)
  mapPalette <- colorRampPalette(c("grey", "yellow", "orange", "red"))
  plot(carsp.r.v, col= mapPalette(100), axes = F, box = FALSE, main ="Small carnivore species richness")
 
### Produce on one figure for cats
  layout(matrix(c(1,3,2,3), 2, 2, byrow = TRUE))
  image(cat.r, col= mapPalette(100), axes = F, box = FALSE, main ="") # cats ND
  image(cat.r.v, col= mapPalette(100), axes = F, box = FALSE, main ="") # cats Vye
  plot(out_ES_MS$summary[12:20,1], 1:9, xlim = c(-4, 4), xlab = "Effect size", ylab = "Species number", main = "Effect of CAT on occupancy")
  abline(v = 0, lwd = 1, col = "black")
  segments(out_ES_MS$summary[12:20,3], 1:9, out_ES_MS$summary[12:20,7], 1:9, col = "grey", lwd = 1)
  sig3.1 <- (out_ES_MS$summary[12:20,3]<0 & out_ES_MS$summary[12:20,7]<0) + (out_ES_MS$summary[12:20,3]>0 & out_ES_MS$summary[12:20,7]>0)
  segments(out_ES_MS$summary[12:20,3][sig3.1==1], (1:9)[sig3.1==1], out_ES_MS$summary[12:20,7][sig3.1==1], (1:9)[sig3.1==1], col = "blue", lwd = 2)
  abline(v=out_ES_MS$summary[6,1], lwd=3, col="red") # mean community effect
  abline(v=out_ES_MS$summary[6,c(3,7)], lwd=2, col="red", lty=2) # 95% BCI
  
### Dogs  
    layout(matrix(c(1,3,2,3), 2, 2, byrow = TRUE))
    image(dog.r, col= mapPalette(100), axes = F, box = FALSE, main ="") # dogs ND
    image(dog.r.v, col= mapPalette(100), axes = F, box = FALSE, main ="") # dogs Vye
    plot(out_ES_MS$summary[35:43,1], 1:9, xlim = c(-4, 4), xlab = "Effect size", ylab = "Species number", main = "Effect of DOG on occupancy")
    abline(v = 0, lwd = 1, col = "black")
    segments(out_ES_MS$summary[35:43,3], 1:9, out_ES_MS$summary[35:43,7], 1:9, col = "grey", lwd = 1)
    sig3.1 <- (out_ES_MS$summary[35:43,3]<0 & out_ES_MS$summary[35:43,7]<0) + (out_ES_MS$summary[35:43,3]>0 & out_ES_MS$summary[35:43,7]>0)
    segments(out_ES_MS$summary[35:43,3][sig3.1==1], (1:9)[sig3.1==1], out_ES_MS$summary[35:43,7][sig3.1==1], (1:9)[sig3.1==1], col = "blue", lwd = 2)
    abline(v=out_ES_MS$summary[8,1], lwd=3, col="red")
    abline(v=out_ES_MS$summary[8,c(3,7)], lwd=2, col="red", lty=2)
    

### Livestock    
    layout(matrix(c(1,3,2,3), 2, 2, byrow = TRUE))
    image(livestock.r, col= mapPalette(100), axes = F, box = FALSE, main ="") # livestock ND
    image(livestock.r.v, col= mapPalette(100), axes = F, box = FALSE, main ="") # livestock Vye
    plot(out_ES_MS$summary[58:66,1], 1:9, xlim = c(-4, 4), xlab = "Effect size", ylab = "Species number", main = "Effect of LIVESTOCK on occupancy")
    abline(v = 0, lwd = 1, col = "black")
    segments(out_ES_MS$summary[58:66,3], 1:9, out_ES_MS$summary[58:66,7], 1:9, col = "grey", lwd = 1)
    sig3.1 <- (out_ES_MS$summary[58:66,3]<0 & out_ES_MS$summary[58:66,7]<0) + (out_ES_MS$summary[58:66,3]>0 & out_ES_MS$summary[58:66,7]>0)
    segments(out_ES_MS$summary[58:66,3][sig3.1==1], (1:9)[sig3.1==1], out_ES_MS$summary[58:66,7][sig3.1==1], (1:9)[sig3.1==1], col = "blue", lwd = 2)
    abline(v=out_ES_MS$summary[10,1], lwd=3, col="red")
    abline(v=out_ES_MS$summary[10,c(3,7)], lwd=2, col="red", lty=2)
   
### Species maps
    layout(matrix(c(1,2,3,4), 2, 2, byrow = TRUE))
    layout.show(4)
    image(carsp.r, col= mapPalette(100), axes = F, box = FALSE, main ="") # ND sp richness
        boxplot(out_ES_MS$summary[153:241,1]~box$land.use[1:89], ylim = c(0, 5), main="",
            xlab="", ylab="Species Richness")
    image(carsp.r.v, col= mapPalette(100), axes = F, box = FALSE, main ="") # VYE sp richness
       boxplot(out_ES_MS$summary[242:323,1]~box$land.use[90:171], ylim = c(0, 5), main="",
            xlab="", ylab="Species Richness")
    
    par(mfrow=c(1,1))

    
### Community response #####
    o.dog <- seq(0, 500,, 10) # dog data
    o.liv <- seq(0, 900,, 10)
    o.cat <- seq(0, 120,, 10)
    o.dat <- seq(0, 50,, 10)
    
    cat.pred <- (o.cat - mean.cat)/sd.cat
    dog.pred <- (o.dog - mean.dog)/sd.dog
    liv.pred <- (o.dog - mean.liv)/sd.liv
    date.pred <- (o.dat - mean.date)/sd.date
    
    length(liv.pred)
    mean(plogis(tmp$mu.lp))
    
    str(tmp <- out_ES_MS$sims.list) 
    nsamp <- length(tmp[[1]])
    predC <- array(NA, dim=c(10, nsamp, 4))
    for (i in 1:nsamp){
      predC[,i,1]<-plogis(tmp$mu.lpsi[i] + tmp$mu.betalpsi1[i]*cat.pred)
      predC[,i,2]<-plogis(tmp$mu.lpsi[i] + tmp$mu.betalpsi2[i]*dog.pred)
      predC[,i,3]<-plogis(tmp$mu.lpsi[i] + tmp$mu.betalpsi3[i]*liv.pred)
      predC[,i,4]<-plogis(tmp$mu.lp[i]   + tmp$mu.betalp1[i]*date.pred)
    }
    
    str(predC)
    pmC <- apply(predC, c(1,3), mean)  
    criC <- apply(predC, c(1,3), function(x) quantile(x, prob = c(0.025, 0.975)))  
    
   par(mfrow = c(1,3))
   
   plot(o.cat, pmC[,1], col="blue", lwd = 3, type = "l", lty=1, frame=F, ylim=c(0,1), xlab="CAT RAI", ylab="Community mean occupancy")
   matlines(o.cat, t(criC[,,1]), col="grey", lty = 1)
   
   plot(o.dog, pmC[,2], col="blue", lwd = 3, type = "l", lty=1, frame=F, ylim=c(0,1), xlab="DOG RAI", ylab="Community mean occupancy")
   matlines(o.dog, t(criC[,,2]), col="grey", lty = 1)
   
   plot(o.liv, pmC[,3], col="blue", lwd = 3, type = "l", lty=1, frame=F, ylim=c(0,1), xlab="Livestock RAI", ylab="Community mean occupancy")
   matlines(o.dog, t(criC[,,3]), col="grey", lty = 1)
   
   plot(o.dat, pmC[,4], col="blue", lwd = 3, type = "l", lty=1, frame=F, ylim=c(0,1), xlab="Julian day", ylab="Community mean occupancy")
   matlines(o.dat, t(criC[,,3]), col="grey", lty = 1)
   
   par(mfrow=c(1,1))
######   
   
########################### END OF ANALYSIS ##############################################   
   
########################### TO EXTRAXT SUP DATA ##########################################
##########################################################################################
   
### Table S3-1Grab Posterior summaries of species-specific occupancy intercepts   
   
out.summary<-data.frame(out_ES_MS$summary)
 
TableS3.1<-rbind.data.frame((out_ES_MS$summary[3,c(1,2,3,5,7)]),(out_ES_MS$summary[5,c(1,2,3,5,7)]),
                            (out_ES_MS$summary[4,c(1,2,3,5,7)]),(out_ES_MS$summary[1,c(1,2,3,5,7)]), 
                            (out_ES_MS$summary[2,c(1,2,3,5,7)]),(out_ES_MS$summary[6,c(1,2,3,5,7)]),
                            (out_ES_MS$summary[8,c(1,2,3,5,7)]),(out_ES_MS$summary[10,c(1,2,3,5,7)]),
                            (out_ES_MS$summary[7,c(1,2,3,5,7)]),(out_ES_MS$summary[9,c(1,2,3,5,7)]),
                            (out_ES_MS$summary[11,c(1,2,3,5,7)]))

colnames(TableS3.1)<-c("Mean", "SE", "2.5%", "50%", "97.5%") 
rownames(TableS3.1)<-c("up", "op", "udate", "upsi", "opsi", "ucat", "udog", "ulive", "ocat", "odog", "oliv")

   
TableS3.2<-data.frame(c(out.summary[82:90,1]),(out.summary[82:90,2]),(out.summary[82:90,3]),(out.summary[82:90,4]),(out.summary[82:90,7]))   
colnames(TableS3.2)<- c("Mean", "SE", "2.5%", "50%", "97.5%") 
write.csv(TableS3.2, "TableS3.2.csv")

TableS3.3<-data.frame(c(out.summary[12:20,1]),(out.summary[12:20,2]),(out.summary[12:20,3]),(out.summary[12:20,4]),(out.summary[12:20,7]))   
colnames(TableS3.3)<- c("Mean", "SE", "2.5%", "50%", "97.5%") 
write.csv(TableS3.3, "TableS3.3.csv")


TableS3.4<-data.frame(c(out.summary[35:43,1]),(out.summary[35:43,2]),(out.summary[35:43,3]),(out.summary[35:43,4]),(out.summary[35:43,7]))   
colnames(TableS3.4)<- c("Mean", "SE", "2.5%", "50%", "97.5%") 
write.csv(TableS3.4, "TableS3.4.csv")

TableS3.5<-data.frame(c(out.summary[58:66,1]),(out.summary[58:66,2]),(out.summary[58:66,3]),(out.summary[58:66,4]),(out.summary[58:66,7]))   
colnames(TableS3.5)<- c("Mean", "SE", "2.5%", "50%", "97.5%") 
write.csv(TableS3.5, "TableS3.4.csv")

 
TableS3.6<-data.frame(c(out.summary[105:113,1]),(out.summary[105:113,2]),(out.summary[105:113,3]),(out.summary[105:113,4]),(out.summary[105:113,7]))   
colnames(TableS3.6)<- c("Mean", "SE", "2.5%", "50%", "97.5%") 
write.csv(TableS3.6, "TableS3.6.csv")


TableS3.7<-data.frame(c(out.summary[128:136,1]),(out.summary[128:136,2]),(out.summary[128:136,3]),(out.summary[128:136,4]),(out.summary[128:136,7]))   
colnames(TableS3.7)<- c("Mean", "SE", "2.5%", "50%", "97.5%") 
write.csv(TableS3.7, "TableS3.7.csv")


#######################################################################################
#######################################################################################
#######################################################################################


#####################
# Publication figures
#####################

# load species list
sp.list <- read.csv("species names.csv")
head(sp.list)

# plot effect of cat on occupancy
library(ggplot2)
library(stats)
library(dplyr)

catOcc <- data.frame(out_ES_MS$summary[12:20,1])
colnames(catOcc) <- "effect.size"
catOcc$species <- sp.list$sp.name
catOcc$x0 <- out_ES_MS$summary[12:20,3]
catOcc$x1 <- out_ES_MS$summary[12:20,7]
head(catOcc)
catOcc$overlap <- (out_ES_MS$summary[12:20,3]<0 & out_ES_MS$summary[12:20,7]<0) + (out_ES_MS$summary[12:20,3]>0 & out_ES_MS$summary[12:20,7]>0) # scores CIs that don't overlap 0 with "1", and those that do overlap 0 with "0". 
catOccOver <- filter(catOcc, overlap == 1)
head(catOccOver)

pCatOcc <- ggplot() + 
 geom_vline(xintercept = 0, col = "Grey", size = 1.2, alpha = 0.9) + # zero
 geom_vline(xintercept = out_ES_MS$summary[6,1], colour = "red") + # mean community effect
 geom_vline(xintercept = out_ES_MS$summary[6,3], colour = "red", lty=2) + # 95% BCI
 geom_vline(xintercept = out_ES_MS$summary[6,7], colour = "red", lty=2) + # 95% BCI
 geom_errorbarh(data=catOcc, mapping=aes(y=species, x=effect.size, xmin=x0, xmax=x1), height=0.2, size=0.5) + 
 geom_errorbarh(data=catOccOver, mapping=aes(y=species, x=effect.size, xmin=x0, xmax=x1), height=0.2, size=0.5, colour = "dodgerblue1") + 
 geom_point(data=catOcc, mapping=aes(y=species, x=effect.size, col = species)) +
 scale_color_brewer(palette="Set1") +
 theme_bw() +
 scale_x_continuous(limits = c(-4, 4)) +
 labs(x = "Effect size", y = "") + 
 # theme(axis.title.y=element_blank()) +
 theme(axis.title.x=element_blank()) +
 theme(legend.position="none")
pCatOcc
ggsave("pCatOcc.pdf", width = 100, height = 50, units = "mm")

# plot effect of dog on occupancy
### Dogs  

dogOcc <- data.frame(out_ES_MS$summary[35:43,1])
colnames(dogOcc) <- "effect.size"
dogOcc$species <- sp.list$sp.name
dogOcc$x0 <- out_ES_MS$summary[35:43,3]
dogOcc$x1 <- out_ES_MS$summary[35:43,7]
head(dogOcc)
dogOcc$overlap <- (out_ES_MS$summary[35:43,3]<0 & out_ES_MS$summary[35:43,7]<0) + (out_ES_MS$summary[35:43,3]>0 & out_ES_MS$summary[35:43,7]>0) # scores CIs that don't overlap 0 with "1", and those that do overlap 0 with "0". 
dogOccOver <- filter(dogOcc, overlap == 1)
head(dogOccOver)

pDogOcc <- ggplot() + 
 geom_vline(xintercept = 0, col = "Grey", size = 1.2, alpha = 0.9) + # zero
 geom_vline(xintercept = out_ES_MS$summary[8,1], colour = "red") + # mean community effect
 geom_vline(xintercept = out_ES_MS$summary[8,3], colour = "red", lty=2) + # 95% BCI
 geom_vline(xintercept = out_ES_MS$summary[8,7], colour = "red", lty=2) + # 95% BCI
 geom_errorbarh(data=dogOcc, mapping=aes(y=species, x=effect.size, xmin=x0, xmax=x1), height=0.2, size=0.5) + 
 geom_errorbarh(data=dogOccOver, mapping=aes(y=species, x=effect.size, xmin=x0, xmax=x1), height=0.2, size=0.5, colour = "dodgerblue1") + 
 geom_point(data=dogOcc, mapping=aes(y=species, x=effect.size, col = species)) +
 theme_bw() +
 scale_x_continuous(limits = c(-4, 4)) +
 labs(x = "Effect size", y = "") +
 scale_color_brewer(palette="Set1") +
 # theme(axis.title.y=element_blank()) +
 theme(axis.title.x=element_blank()) +
 theme(legend.position="none")
pDogOcc
ggsave("pDogOcc.pdf", width = 100, height = 50, units = "mm")

# plot effect of livestock on occupancy

lsOcc <- data.frame(out_ES_MS$summary[58:66,1])
colnames(lsOcc) <- "effect.size"
lsOcc$species <- sp.list$sp.name
lsOcc$x0 <- out_ES_MS$summary[58:66,3]
lsOcc$x1 <- out_ES_MS$summary[58:66,7]
head(lsOcc)
lsOcc$overlap <- (out_ES_MS$summary[58:66,3]<0 & out_ES_MS$summary[58:66,7]<0) + (out_ES_MS$summary[58:66,3]>0 & out_ES_MS$summary[58:66,7]>0) # scores CIs that don't overlap 0 with "1", and those that do overlap 0 with "0". 
lsOccOver <- filter(lsOcc, overlap == 1)
head(lsOccOver)


pLSOcc <- ggplot() +
 geom_vline(xintercept = 0, col = "Grey", size = 1.2, alpha = 0.9) + # zero
 geom_vline(xintercept = out_ES_MS$summary[10,1], colour = "red") + # mean community effect
 geom_vline(xintercept = out_ES_MS$summary[10,3], colour = "red", lty=2) + # 95% BCI
 geom_vline(xintercept = out_ES_MS$summary[10,7], colour = "red", lty=2) + # 95% BCI
 geom_errorbarh(data=lsOcc, mapping=aes(y=species, x=effect.size, xmin=x0, xmax=x1), height=0.2, size=0.5) +
 geom_errorbarh(data=lsOccOver, mapping=aes(y=species, x=effect.size, xmin=x0, xmax=x1), height=0.2, size=0.5, colour = "dodgerblue1") + 
 geom_point(data=lsOcc, mapping=aes(y=species, x=effect.size, col = species)) +
 theme_bw() +
 scale_x_continuous(limits = c(-4, 4)) +
 labs(x = "Effect size", y = "") +
 scale_color_brewer(palette="Set1") +
 # theme(axis.title.y=element_blank()) +
 theme(legend.position="none")
pLSOcc
ggsave("pLSOcc.pdf", width = 100, height = 50, units = "mm")


###
# Boxplots species richness per land use 
###

box <- read.table("box1.txt", header = TRUE)

# Ka-Ndengeza species richness LUT boxplot
box.ka.y <- out_ES_MS$summary[153:241,1]
box.ka.x <- box$land.use[1:89]
box.ka <- data.frame(box.ka.y, box.ka.x)
head(box.ka)

library(ggsci)# for colour pallate

pBoxKa <- ggplot(data = box.ka, aes(x = box.ka.x, y=box.ka.y, fill = box.ka.x)) + 
 stat_boxplot(geom ='errorbar', width = 0.2) + # adds ends to whiskers
 geom_boxplot() + # 	length of the whiskers as multiple of IQR. Defaults to 1.5
 scale_fill_npg(alpha = 0.6) + # colour palatte
 theme_bw() +
 scale_y_continuous(limits = c(0, 5)) +
 labs(x = "Land use type", y = "Species richness") + 
 theme(legend.position="none")
pBoxKa
ggsave("pBoxKa.pdf", width = 10.4, height = 7, units = "cm")

# Vyeboom species richness LUT boxplot
box.vy.y <- out_ES_MS$summary[242:323,1]
box.vy.x <- box$land.use[90:171]
box.vy <- data.frame(box.vy.y, box.vy.x)
head(box.vy)

pBoxVy <- ggplot(data = box.vy, aes(x = box.vy.x, y=box.vy.y, fill = box.vy.x)) + 
 stat_boxplot(geom ='errorbar', width = 0.2) + # adds ends to whiskers
 geom_boxplot() + # 	length of the whiskers as multiple of IQR. Defaults to 1.5
 scale_fill_npg(alpha = 0.6) + # colour palatte
 theme_bw() +
 scale_y_continuous(limits = c(0, 5)) +
 labs(x = "Land use type", y = "Species richness") +
 theme(legend.position="none")
pBoxVy
ggsave("pBoxVy.pdf", width = 10.4, height = 7, units = "cm")


################################################################################
#################################  mappping #################################
################################################################################

####################
# Species richness
####################

# Ka-Ndengeza 

# rename rasters
richness.ka <- carsp.r
richness.vy <- carsp.r.v

# read LUT shapefile
LUT <- readOGR("LUT detailed.shp") 


# Species richness at Ka-Ndengeza

library(tmap)
pRichness.ka <- tm_shape(richness.ka, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add raster
  tm_raster("var1.pred", legend.show = FALSE, style = "equal", breaks = "equal", palette = "-Spectral", n = 1000, interpolate = TRUE, auto.palette.mapping = FALSE) + # raster details
 tm_shape(LUT, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add LUT shapefile
 tm_polygons("LUT", alpha = 0.3, legend.show = FALSE, palette = "Greys", n = 3, contrast = c(0, 1)) + # shapefile details
 # tm_scale_bar(size= 1, width = 0.25) + # add scale bar
 tm_layout(frame = TRUE, frame.lwd = 3) # add frame
pRichness.ka # view plot of cat occupancy in Ka-Ndengeza
save_tmap(pRichness.ka, "fig2a.pdf")


# Species richness at Vyeboom

pRichness.vy <- tm_shape(richness.vy, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add raster
 tm_raster("var1.pred", legend.show = FALSE, style = "equal", breaks = "equal", palette = "-Spectral", n = 1000, interpolate = TRUE, auto.palette.mapping = FALSE) + # raster details
 tm_shape(LUT, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add LUT shapefile
 tm_polygons("LUT", alpha = 0.3, legend.show = FALSE, palette = "Greys", n = 3, contrast = c(0, 1)) + # shapefile details
 # tm_scale_bar(size= 1, width = 0.25) + # add scale bar
 tm_layout(frame = TRUE, frame.lwd = 3) # add frame
pRichness.vy # view plot of cat occupancy in Ka-Ndengeza
save_tmap(pRichness.vy, "fig2c.pdf")


################################
# Relative abundance index (RAI)
################################

########################################
############# preparing data ###########
########################################

# RAI heatmaps for cat, dog and livestock in both villages

# rename RAI heatmap rasters for cats, dogs, and livestock in Ka-Ndengeza and Vyeboom
cat.ka <- cat.r # cat RAI raster in Ka-Ndengeza 
cat.vy <- cat.r.v # cat RAI raster in Vyeboom
dog.ka <- dog.r # dog RAI raster in Ka-Ndengeza 
dog.vy <- dog.r.v # dog RAI raster in Vyeboom
ls.ka <- livestock.r # livestock RAI raster in Ka-Ndengeza 
ls.vy <- livestock.r.v # livestock RAI raster in Vyeboom

# import LUT shapefile
LUT <- readOGR("LUT detailed.shp") # reads land use type (LUT) shapefile


########################################
############# plotting #################
########################################

##################
# RAI at ka 
##################

# Cat RAI at Ka-Ndengeza 

library(tmap)
pCat.ka <- tm_shape(cat.ka, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add raster
 tm_raster("var1.pred", legend.show = FALSE, style = "equal", breaks = "equal", palette = "-Spectral", n = 1000, interpolate = TRUE, auto.palette.mapping = FALSE) + # raster details
 tm_shape(LUT, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add LUT shapefile
 tm_polygons("LUT", alpha = 0.3, legend.show = FALSE, palette = "Greys", n = 3, contrast = c(0, 1)) + # shapefile details
 tm_layout(frame = TRUE, frame.lwd = 3) # add frame
pCat.ka # view plot of cat RAI in Ka-Ndengeza
save_tmap(pCat.ka, "Fig1a.pdf",width = 10.4, height = 7, units = "cm")


# Dog RAI at Ka-Ndengeza 

pDog.ka <- tm_shape(dog.ka, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add raster
 tm_raster("var1.pred", legend.show = FALSE, style = "equal", breaks = "equal", palette = "-Spectral", n = 1000, interpolate = TRUE, auto.palette.mapping = FALSE) + # raster details
 tm_shape(LUT, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add LUT shapefile
 tm_polygons("LUT", alpha = 0.3, legend.show = FALSE, palette = "Greys", n = 3, contrast = c(0, 1)) + # shapefile details
  tm_layout(frame = TRUE, frame.lwd = 3) # add frame
pDog.ka # view plot of dog RAI in Ka-Ndengeza
save_tmap(pDog.ka, "Fig1c.pdf",width = 10.4, height = 7, units = "cm")


# Livestock RAI at Ka-Ndengeza 

pLS.ka <- tm_shape(ls.ka, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add raster
 tm_raster("var1.pred", legend.show = FALSE, style = "equal", breaks = "equal", palette = "-Spectral", n = 1000, interpolate = TRUE, auto.palette.mapping = FALSE) + # raster details
 tm_shape(LUT, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add LUT shapefile
 tm_polygons("LUT", alpha = 0.3, legend.show = FALSE, palette = "Greys", n = 3, contrast = c(0, 1)) + # shapefile details
 tm_layout(frame = TRUE, frame.lwd = 3) # add frame
pLS.ka # view plot of livestock RAI in Ka-Ndengeza
save_tmap(pLS.ka, "Fig1e.pdf",width = 10.4, height = 7, units = "cm")


######################
# Occupancy at Vyeboom 
######################

##################
# Occupancy cat vy 
##################

# Cat RAI at Vyeboom

pCat.vy <- tm_shape(cat.vy, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add raster
 tm_raster("var1.pred", legend.show = FALSE, style = "equal", breaks = "equal", palette = "-Spectral", n = 1000, interpolate = TRUE, auto.palette.mapping = FALSE) + # raster details
 tm_shape(LUT, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add LUT shapefile
 tm_polygons("LUT", alpha = 0.3, legend.show = FALSE, palette = "Greys", n = 3, contrast = c(0, 1)) + # shapefile details
  tm_layout(frame = TRUE, frame.lwd = 3) # add frame
pCat.vy # view plot of cat RAI in Vyeboom
save_tmap(pCat.vy, "Fig1a2.pdf",width = 10.4, height = 7, units = "cm")


# Dog RAI at Vyeboom

pDog.vy <- tm_shape(dog.vy, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add raster
 tm_raster("var1.pred", legend.show = FALSE, style = "equal", breaks = "equal", palette = "-Spectral", n = 1000, interpolate = TRUE, auto.palette.mapping = FALSE) + # raster details
 tm_shape(LUT, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add LUT shapefile
 tm_polygons("LUT", alpha = 0.3, legend.show = FALSE, palette = "Greys", n = 3, contrast = c(0, 1)) + # shapefile details
 tm_layout(frame = TRUE, frame.lwd = 3) # add frame
pDog.vy # view plot of dog RAI in Vyeboom
save_tmap(pDog.vy, "Fig1c2.pdf",width = 10.4, height = 7, units = "cm")


# Livestock occupancy at Vyeboom

pLS.vy <- tm_shape(ls.vy, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add raster
 tm_raster("var1.pred", legend.show = FALSE, style = "equal", breaks = "equal", palette = "-Spectral", n = 1000, interpolate = TRUE, auto.palette.mapping = FALSE) + # raster details
 tm_shape(LUT, projection="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") + # add LUT shapefile
 tm_polygons("LUT", alpha = 0.3, legend.show = FALSE, palette = "Greys", n = 3, contrast = c(0, 1)) + # shapefile details
 tm_layout(frame = TRUE, frame.lwd = 3) # add frame
pLS.vy # view plot of livestock RAI in Vyeboom
save_tmap(pLS.vy, "Fig1e2.pdf",width = 10.4, height = 7, units = "cm")

# End